@@ -3,7 +3,8 @@
 # TODO: ...
 
 ################################################################################
-# CHANGE LOG
+# CHANGE LOG (last 20 changes)
+# 11.10.2014: Added 'focus', added 'parent' parameter.
 # 28.06.2014: Added help button and moved save gui checkbox.
 # 06.01.2014: Fixed button name used as 'save as' name.
 # 20.11.2013: Fixed result now stored in variable 'datanew' insted of 'val_name'.
@@ -29,6 +30,7 @@
 #' @param env environment in wich to search for data frames and save result.
 #' @param savegui logical indicating if GUI settings should be saved in the environment.
 #' @param debug logical indicating printing debug information.
+#' @param parent widget to get focus when finished.
 #' 
 #' @return TRUE
 #' 
@@ -36,7 +38,7 @@
 #' 
 #' @seealso \code{\link{calculateOverlap}}
 
-calculateOverlap_gui <- function(env=parent.frame(), savegui=NULL, debug=TRUE){
+calculateOverlap_gui <- function(env=parent.frame(), savegui=NULL, debug=TRUE, parent=NULL){
   
   if(debug){
     print(paste("IN:", match.call()[[1]]))
@@ -45,9 +47,17 @@ calculateOverlap_gui <- function(env=parent.frame(), savegui=NULL, debug=TRUE){
   # Main window.
   w <- gwindow(title="Analyse bins overlap", visible=FALSE)
   
-  # Handler for saving GUI state.
+  # Runs when window is closed.
   addHandlerDestroy(w, handler = function (h, ...) {
+    
+    # Save GUI state.
     .saveSettings()
+    
+    # Focus on parent window.
+    if(!is.null(parent)){
+      focus(parent)
+    }
+    
   })
   
   gv <- ggroup(horizontal=FALSE,
@@ -515,5 +525,6 @@ calculateOverlap_gui <- function(env=parent.frame(), savegui=NULL, debug=TRUE){
   
   # Show GUI.
   visible(w) <- TRUE
+  focus(w)
   
 }
