@@ -3,7 +3,8 @@
 # TODO: ...
 
 ################################################################################
-# CHANGE LOG
+# CHANGE LOG (last 20 changes)
+# 11.10.2014: Added 'focus', added 'parent' parameter.
 # 28.06.2014: Added help button and moved save gui checkbox.
 # 08.05.2014: Implemented 'checkDataset'.
 # 11.01.2014: First version.
@@ -20,6 +21,7 @@
 #' @param env environment in wich to search for data frames.
 #' @param savegui logical indicating if GUI settings should be saved in the environment.
 #' @param debug logical indicating printing debug information.
+#' @param parent widget to get focus when finished.
 #' 
 #' @return TRUE
 #' 
@@ -27,7 +29,7 @@
 #' 
 #' @seealso \code{\link{calculatePeaks}}
 
-calculatePeaks_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
+calculatePeaks_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE, parent=NULL){
   
   .gData <- NULL
   .gDataName <- NULL
@@ -38,11 +40,19 @@ calculatePeaks_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
   
   w <- gwindow(title="Calculate peaks", visible=FALSE)
   
-  # Handler for saving GUI state.
+  # Runs when window is closed.
   addHandlerDestroy(w, handler = function (h, ...) {
+    
+    # Save GUI state.
     .saveSettings()
+    
+    # Focus on parent window.
+    if(!is.null(parent)){
+      focus(parent)
+    }
+    
   })
-
+  
   gv <- ggroup(horizontal=FALSE,
                spacing=8,
                use.scrollwindow=FALSE,
@@ -200,7 +210,7 @@ calculatePeaks_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
       
       # Close GUI.
       dispose(w)
-    
+      
     } else {
       
       message <- "A dataset has to be selected."
@@ -305,5 +315,6 @@ calculatePeaks_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE){
   
   # Show GUI.
   visible(w) <- TRUE
+  focus(w)
   
 }
